@@ -118,6 +118,12 @@ enum drbd_packet {
 	P_OV_RESULT_ID        = 0x53, /* meta sock: Online verify result with block ID. */
 	P_RS_DEALLOCATED_ID   = 0x54, /* data sock: Contains only zeros on sync source node. */
 
+	P_FLUSH_REQUESTS      = 0x55, /* data sock: Flush prior requests then send ack and/or forward */
+	P_FLUSH_FORWARD       = 0x56, /* meta sock: Send ack after sending P_OUT_OF_SYNC for prior P_PEER_ACK */
+	P_FLUSH_REQUESTS_ACK  = 0x57, /* data sock: Response to initiator of P_FLUSH_REQUESTS */
+	P_ENABLE_REPLICATION_NEXT = 0x58, /* data sock: whether to start replication on next resync start */
+	P_ENABLE_REPLICATION  = 0x59, /* data sock: enable or disable replication during resync */
+
 	P_MAY_IGNORE	      = 0x100, /* Flag to test if (cmd > P_MAY_IGNORE) ... */
 
 	/* special command ids for handshake */
@@ -364,6 +370,10 @@ struct p_rs_req {
  */
 #define DRBD_FF_RS_SKIP_UUID 64
 
+/* Support for resync_without_replication.
+ */
+#define DRBD_FF_RESYNC_WITHOUT_REPLICATION 128
+
 struct p_connection_features {
 	uint32_t protocol_min;
 	uint32_t feature_flags;
@@ -674,6 +684,26 @@ struct p_peer_dagtag {
 	uint32_t node_id;
 } __packed;
 
+struct p_flush_requests {
+	uint64_t flush_sequence;
+} __packed;
+
+struct p_flush_forward {
+	uint64_t flush_sequence;
+	uint32_t initiator_node_id;
+} __packed;
+
+struct p_flush_ack {
+	uint64_t flush_sequence;
+	uint32_t primary_node_id;
+} __packed;
+
+struct p_enable_replication {
+       uint8_t enable;
+       uint8_t _pad1;
+       uint16_t _pad2;
+} __packed;
+
 /*
  * Bitmap packets need to fit within a single page on the sender and receiver,
  * so we are limited to 4 KiB (and not to PAGE_SIZE, which can be bigger).
