@@ -88,14 +88,13 @@
 #define DRBD_MAX_EPOCH_SIZE_DEF 2048U
 #define DRBD_MAX_EPOCH_SIZE_SCALE '1'
 
-  /* I don't think that a tcp send buffer of more than 10M is useful */
 #define DRBD_SNDBUF_SIZE_MIN  0U
-#define DRBD_SNDBUF_SIZE_MAX  (10U<<20)
+#define DRBD_SNDBUF_SIZE_MAX  (128U<<20)
 #define DRBD_SNDBUF_SIZE_DEF  0U
 #define DRBD_SNDBUF_SIZE_SCALE '1'
 
 #define DRBD_RCVBUF_SIZE_MIN  0U
-#define DRBD_RCVBUF_SIZE_MAX  (10U<<20)
+#define DRBD_RCVBUF_SIZE_MAX  (128U<<20)
 #define DRBD_RCVBUF_SIZE_DEF  0U
 #define DRBD_RCVBUF_SIZE_SCALE '1'
 
@@ -233,6 +232,7 @@
 #define DRBD_CSUMS_AFTER_CRASH_ONLY_DEF 0U
 #define DRBD_AUTO_PROMOTE_DEF	1U
 #define DRBD_BITMAP_DEF         1U
+#define DRBD_RESYNC_WITHOUT_REPLICATION_DEF 1U
 
 #define DRBD_NR_REQUESTS_MIN	4U
 #define DRBD_NR_REQUESTS_DEF	8000U
@@ -317,6 +317,7 @@
 #define DRBD_ON_NO_QUORUM_DEF ONQ_SUSPEND_IO
 
 #define DRBD_ON_SUSP_PRI_OUTD_DEF SPO_DISCONNECT
+#define DRBD_DRBD8_COMPAT_MODE_DEF 0U
 
 #define DRBD_TLS_DEF 0U /* disabled by default */
 #define DRBD_TLS_PRIVKEY_DEF 0 /* disabled by default */
