@@ -1,10 +1,10 @@
 #ifndef WINDRBD_IOCTL_H
 #define WINDRBD_IOCTL_H
 
-#include <sys/types.h>			/* for int64_t */
-
 #ifdef __CYGWIN__
 
+#include <sys/types.h>			/* for int64_t */
+
 	/* Windows user space (Cygwin, for drbd-utils) */
 
 #ifndef GENL_NAMSIZ
@@ -103,8 +103,6 @@ struct windrbd_ioctl_genl_portid_and_multicast_group {
  * the actual size is returned by the lpBytesReturned parameter to
  * DeviceIoControl().
  *
- * Does not wait for packets to arrive, use POLL ioctl for waiting for
- * packets.
  */
 
 #define IOCTL_WINDRBD_ROOT_RECEIVE_NL_PACKET CTL_CODE(WINDRBD_ROOT_DEVICE_TYPE, 4, METHOD_BUFFERED, FILE_ANY_ACCESS)
@@ -318,4 +316,67 @@ struct windrbd_minor_mount_point {
 
 #define IOCTL_WINDRBD_ROOT_SET_SHUTDOWN_FLAG CTL_CODE(WINDRBD_ROOT_DEVICE_TYPE, 18, METHOD_BUFFERED, FILE_ANY_ACCESS)
 
+/* Check if there is a netlink packet without consuming it.
+ *
+ * Input buffer: the port id (getpid()) in a struct windrbd_ioctl_genl_portid
+ * Output buffer: a 32 bit flag: 0 - no netlink packets 1 - there are netlink
+ *                packets.
+ */
+
+#define IOCTL_WINDRBD_ROOT_ARE_THERE_NL_PACKETS CTL_CODE(WINDRBD_ROOT_DEVICE_TYPE, 19, METHOD_BUFFERED, FILE_ANY_ACCESS)
+
+/* Lock or unlock driver in memory
+ * Input: 0 - Set AddDevice to NULL (if otherwise unused) driver can be unloaded
+ *        1 - Set AddDevice to valid AddDevice function, driver cannot be unloaded
+ * Output: none
+ *
+ * Controls whether WinDRBD is reacting to new devices (such as the bus device)
+ * This allows to remove the bus driver and install it again without having
+ * to unload the driver or reboot the system.
+ */
+
+#define IOCTL_WINDRBD_ROOT_SET_DRIVER_LOCKED CTL_CODE(WINDRBD_ROOT_DEVICE_TYPE, 20, METHOD_BUFFERED, FILE_ANY_ACCESS)
+
+/* Suspend/Resume I/O for a minor on the WinDRBD level (outside DRBD)
+ *
+ * Input: minor - the DRBD minor for which to suspend I/O for
+ * Output: none
+ *
+ * When an application busy writes a block it may happen that
+ * syncing never finished. In that case, set this suspend-io
+ * flag, wait for sync to finish and then clear the suspend-io
+ * flag again. Note that this is different from DRBD's suspend-io
+ * command.
+ */
+
+#define IOCTL_WINDRBD_ROOT_SET_IO_SUSPENDED_FOR_MINOR CTL_CODE(WINDRBD_ROOT_DEVICE_TYPE, 21, METHOD_BUFFERED, FILE_ANY_ACCESS)
+#define IOCTL_WINDRBD_ROOT_CLEAR_IO_SUSPENDED_FOR_MINOR CTL_CODE(WINDRBD_ROOT_DEVICE_TYPE, 22, METHOD_BUFFERED, FILE_ANY_ACCESS)
+
+/* Check if DRBD implements a certain command on the netlink layer
+ *
+ * Input: cmd (as an 32-bit int) to query
+ * Output: 0 - does not implement command, 1 - implements command
+ *
+ * Newer drbd-utils query the netlink family of the Linux
+ * kernel for known commands. We don't implement a full
+ * netlink replacement but still want to query the kernel
+ * for commands it knows. Therefore we introduced this ioctl
+ * which checks if a certain command is known.
+ */
+
+#define IOCTL_WINDRBD_ROOT_DRBD_OP_IS_KNOWN CTL_CODE(WINDRBD_ROOT_DEVICE_TYPE, 23, METHOD_BUFFERED, FILE_ANY_ACCESS)
+
+/* Check if the WinDRBD virtual bus device is working correctly
+ *
+ * Input: none
+ * Output: 0 - does NOT work correctly 1 - works as expected
+ *
+ * Sometimes the WinDRBD bus device does not work correctly after
+ * a new install. The reason for that is yet unknown but we know
+ * how to fix it. In order to allow the installer to apply the fix
+ * we need a possibility to check if the bus device works as expected.
+ */
+
+#define IOCTL_WINDRBD_ROOT_BUS_DEVICE_IS_WORKING CTL_CODE(WINDRBD_ROOT_DEVICE_TYPE, 24, METHOD_BUFFERED, FILE_ANY_ACCESS)
+
 #endif
