@@ -3,7 +3,7 @@
 
 #include <default_types.h>
 #include <configuration/CfgEntry.h>
-#include <configuration/IoException.h>
+#include <platform/IoException.h>
 #include <istream>
 #include <ostream>
 
