@@ -1,6 +1,6 @@
 #include <default_types.h>
 #include <persistent_configuration.h>
-#include <configuration/IoException.h>
+#include <platform/IoException.h>
 #include <configuration/CfgEntryStore.h>
 #include <configuration/CfgEntryBoolean.h>
 #include <configuration/CfgEntryIntegerTypes.h>
@@ -10,6 +10,7 @@
 #include <fstream>
 #include <iostream>
 #include <iomanip>
+#include <system_error>
 #include <dsaext.h>
 #include <integerparse.h>
 
@@ -50,6 +51,7 @@ namespace configuration
         SystemApi&          sys_api
     )
     {
+        sys_api.prepare_save_config_file();
         std::ofstream data_out(file_path);
         config.save_to(config_store);
         config_store.save_to(data_out);
@@ -276,11 +278,14 @@ namespace configuration
                 if (new_entry != nullptr)
                 {
                     config_store.set_entry(new_entry.get());
+                    // New entry linked into the configuration, release immediately to prevent deallocation
+                    // if saving the configuration throws.
+                    CfgEntry* const changed_entry = new_entry.release();
                     entry = nullptr;
 
+                    mon_env.sys_api->prepare_save_config_file();
                     std::ofstream data_out(mon_env.config_file_path);
                     config_store.save_to(data_out);
-                    CfgEntry* const changed_entry = new_entry.release();
 
                     std::cout << "Changed configuration entry:\n";
                     display_entry(changed_entry);
