@@ -4,6 +4,7 @@
 #include <default_types.h>
 #include <memory>
 #include <string>
+#include <stdexcept>
 #include <MessageLog.h>
 #include <subprocess/SubProcess.h>
 #include <terminal/TerminalControl.h>
@@ -26,6 +27,7 @@ class SystemApi
     virtual std::unique_ptr<SubProcess> create_subprocess_handler() = 0;
     virtual std::unique_ptr<TerminalControl> create_terminal_control() = 0;
     virtual std::string get_config_file_path() = 0;
+    virtual void prepare_save_config_file() = 0;
     virtual std::string file_name_for_path(const std::string path) const = 0;
     virtual bool is_file_accessible(const char* const file_path) const = 0;
 };
