@@ -4,12 +4,15 @@
 #include <terminal/DisplayConsts.h>
 #include <terminal/MouseEvent.h>
 #include <terminal/InputField.h>
+#include <terminal/GlobalCommandConsts.h>
 #include <cppdsaext/src/integerparse.h>
 #include <cppdsaext/src/dsaext.h>
 #include <string_transformations.h>
 #include <bounds.h>
 #include <algorithm>
 
+const std::string   MDspBase::KEYWORD_PAGE_LAST("LAST");
+
 MDspBase::MDspBase(const ComponentsHub& comp_hub):
     dsp_comp_hub(comp_hub)
 {
@@ -176,29 +179,10 @@ bool MDspBase::key_pressed(const uint32_t key)
     else
     if (base_input_mode == base_input_mode_type::COMMAND)
     {
-        const DisplayCommon::command_state_type state = dsp_comp_hub.dsp_common->command_line_key_pressed(key);
-        bool exit_cmd_mode = false;
-        if (state == DisplayCommon::command_state_type::CMD_LOCAL)
-        {
-            StringTokenizer tokenizer(dsp_comp_hub.command_line->get_text(), DisplayConsts::CMD_TOKEN_DELIMITER);
-            if (tokenizer.has_next())
-            {
-                std::string keyword(tokenizer.next());
-                if (keyword.length() >= 2)
-                {
-                    keyword.erase(0, 1);
-                    std::string upper_keyword = string_transformations::uppercase_copy_of(keyword);
-                    exit_cmd_mode = execute_command(upper_keyword, tokenizer);
-                }
-            }
-        }
-        else
+        const DisplayCommon::command_state_type state = dsp_comp_hub.dsp_common->command_line_key_pressed(
+            key, *this
+        );
         if (state != DisplayCommon::command_state_type::INPUT)
-        {
-            exit_cmd_mode = true;
-        }
-
-        if (exit_cmd_mode)
         {
             base_input_mode = base_input_mode_type::GLOBAL_KEYS;
             dsp_comp_hub.dsp_io->write_text(dsp_comp_hub.ansi_ctl->ANSI_CURSOR_OFF.c_str());
@@ -450,6 +434,46 @@ void MDspBase::base_enter_page_nav_mode()
 }
 
 bool MDspBase::execute_command(const std::string& command, StringTokenizer& tokenizer)
+{
+    bool cmd_valid = false;
+    if (command == cmd_names::KEY_CMD_PAGE)
+    {
+        if (tokenizer.has_next())
+        {
+            const std::string arg_page = tokenizer.next();
+            if (!tokenizer.has_next())
+            {
+                try
+                {
+                    const uint32_t arg_page_nr = dsaext::parse_unsigned_int32(arg_page);
+                    if (arg_page_nr >= 1 && arg_page_nr <= DisplayConsts::MAX_PAGE_NR)
+                    {
+                        set_page_nr(arg_page_nr);
+                        leave_page_nav_mode(page_change_type::PG_CHG_CHANGED);
+                        cmd_valid = true;
+                    }
+                }
+                catch (dsaext::NumberFormatException&)
+                {
+                    const std::string upper_arg_page = string_transformations::uppercase_copy_of(arg_page);
+                    if (upper_arg_page == KEYWORD_PAGE_LAST)
+                    {
+                        set_page_nr(DisplayConsts::MAX_PAGE_NR);
+                        leave_page_nav_mode(page_change_type::PG_CHG_CHANGED);
+                        cmd_valid = true;
+                    }
+                }
+            }
+        }
+    }
+    else
+    {
+        cmd_valid = execute_custom_command(command, tokenizer);
+    }
+    return cmd_valid;
+}
+
+bool MDspBase::execute_custom_command(const std::string& command, StringTokenizer& tokenizer)
 {
     return false;
 }
