@@ -666,7 +666,7 @@ bool MDspConnections::mouse_action(MouseEvent& mouse)
     return intercepted;
 }
 
-bool MDspConnections::execute_command(const std::string& command, StringTokenizer& tokenizer)
+bool MDspConnections::execute_custom_command(const std::string& command, StringTokenizer& tokenizer)
 {
     bool accepted = false;
     if (command == cmd_names::KEY_CMD_CURSOR)
