@@ -142,7 +142,7 @@ bool MDspPeerVolumes::mouse_action(MouseEvent& mouse)
     return intercepted;
 }
 
-bool MDspPeerVolumes::execute_command(const std::string& command, StringTokenizer& tokenizer)
+bool MDspPeerVolumes::execute_custom_command(const std::string& command, StringTokenizer& tokenizer)
 {
     bool accepted = false;
     if (command == cmd_names::KEY_CMD_CURSOR)
