@@ -587,7 +587,7 @@ bool MDspResources::mouse_action(MouseEvent& mouse)
     return intercepted;
 }
 
-bool MDspResources::execute_command(const std::string& command, StringTokenizer& tokenizer)
+bool MDspResources::execute_custom_command(const std::string& command, StringTokenizer& tokenizer)
 {
     bool accepted = false;
     if (command == cmd_names::KEY_CMD_CURSOR)
