@@ -322,7 +322,7 @@ bool MDspTaskQueue::mouse_action(MouseEvent& mouse)
     return intercepted;
 }
 
-bool MDspTaskQueue::execute_command(const std::string& command, StringTokenizer& tokenizer)
+bool MDspTaskQueue::execute_custom_command(const std::string& command, StringTokenizer& tokenizer)
 {
     bool accepted = false;
     if (command == cmd_names::KEY_CMD_SELECT_ALL)
