@@ -43,7 +43,7 @@ class MDspTaskQueue : public MDspStdListBase
 
     virtual bool key_pressed(const uint32_t key) override;
     virtual bool mouse_action(MouseEvent& mouse) override;
-    virtual bool execute_command(const std::string& command, StringTokenizer& tokenizer);
+    virtual bool execute_custom_command(const std::string& command, StringTokenizer& tokenizer) override;
 
     virtual void cursor_to_next_item() override;
     virtual void cursor_to_previous_item() override;
