@@ -105,7 +105,8 @@ extern void ensure_sanity_of_res_name(char *stg);
 
 extern bool addr_scope_local(const char *input);
 
-extern unsigned long long m_strtoll(const char* s,const char def_unit);
+extern void print_strtoll_error_and_exit(int err, const char *s, char def_unit);
+extern unsigned long long m_strtoll(const char* s, char def_unit);
 extern int only_digits(const char *s);
 extern int dt_lock_drbd(int minor);
 extern void dt_unlock_drbd(int lock_fd);
@@ -115,8 +116,8 @@ extern void dt_pretty_print_gc(const uint32_t* gen_cnt);
 
 extern void initialize_logging(void);
 extern int log_err(const char *format, ...);
-extern const char *esc_xml(char *str);
-extern const char *esc(char *str);
+extern const char *esc_xml(const char *str);
+extern const char *esc(const char *str);
 
 bool ipv4_addresses_match(const char *addr_1st, const char *addr_2nd);
 
