@@ -106,6 +106,22 @@ void usage_and_exit(void)
 	fprintf(stderr, "		Erases DRBD meta data from drive if it exists\n");
 	fprintf(stderr, "	windrbd [opt] set-shutdown-flag <0 or 1>\n");
 	fprintf(stderr, "		Tells WinDRBD driver to stop all drbdsetup processes (when flag=1)\n");
+	fprintf(stderr, "	windrbd [opt] lock-driver\n");
+	fprintf(stderr, "		Tells WinDRBD driver to react to AddDevice requests.\n");
+	fprintf(stderr, "		The driver cannot be unloaded, then.\n");
+	fprintf(stderr, "	windrbd [opt] unlock-driver\n");
+	fprintf(stderr, "		Tells WinDRBD driver not to reacto to AddDevice requests.\n");
+	fprintf(stderr, "		This works only when the usage count is 0 (no DRBD resources, no bus devices)\n");
+	fprintf(stderr, "		The driver can be unloaded, then.\n");
+	fprintf(stderr, "	windrbd [opt] suspend-io-for-minor <minor>\n");
+	fprintf(stderr, "		Tells WinDRBD driver to suspend I/O by not submitting.\n");
+	fprintf(stderr, "		I/O requests to the DRBD engine.\n");
+	fprintf(stderr, "	windrbd [opt] resume-io-for-minor <minor>\n");
+	fprintf(stderr, "		Tells WinDRBD driver to resume I/O by submitting.\n");
+	fprintf(stderr, "		I/O requests (including the suspended ones) to the DRBD engine.\n");
+	fprintf(stderr, "	windrbd [opt] bus-device-is-working\n");
+	fprintf(stderr, "		Queries WinDRBD driver if it can access the bus device\n");
+	fprintf(stderr, "		Exit status is 0 (success) if bus device is working.\n");
 
 	fprintf(stderr, "Options are:\n");
 	fprintf(stderr, "	-q (quiet): be a little less verbose.\n");
@@ -114,6 +130,20 @@ void usage_and_exit(void)
 	exit(1);
 }
 
+void timestamp(void)
+{
+	char the_time[80];
+	struct timeval tv;
+	struct tm nowtm;
+	time_t nowtime;
+
+	gettimeofday(&tv, NULL);
+	nowtime = tv.tv_sec;
+	localtime_r(&nowtime, &nowtm);
+	strftime(the_time, sizeof(the_time), "%Y-%m-%d %H:%M:%S", &nowtm);
+	printf("%s.%06ld ", the_time, tv.tv_usec);
+}
+
 	/* TODO: move those to user/shared/windrbd_helper.c */
 
 enum volume_spec { VS_UNKNOWN, VS_DRIVE_LETTER, VS_GUID };
@@ -407,6 +437,67 @@ static int dismount_volume(HANDLE h)
 	return 0;
 }
 
+static int update_size(const char *drive)
+{
+	BOOL ret;
+	int err;
+	HANDLE h = do_open_device(drive);
+	if (h == INVALID_HANDLE_VALUE) {
+		return 1;
+	}
+
+	ret = DeviceIoControl(h, IOCTL_DISK_UPDATE_PROPERTIES, NULL, 0, NULL, 0, NULL, NULL);
+	if (ret) {
+		printf("Device size updated.\n");
+	} else {
+		err = GetLastError();
+		printf("Could not update device size (error code %d)\n", err);
+		return 1;
+	}
+	return 0;
+}
+
+static int update_size2(const char *drive, unsigned long long delta)
+{
+	BOOL ret;
+	int err;
+	HANDLE h = do_open_device(drive);
+	struct _DRIVE_LAYOUT_INFORMATION_EX l;
+
+	if (h == INVALID_HANDLE_VALUE) {
+		return 1;
+	}
+
+	ret = DeviceIoControl(h, IOCTL_DISK_GET_DRIVE_LAYOUT_EX, NULL, 0, &l, sizeof(l), NULL, NULL);
+	if (ret) {
+		printf("Got device size.\n");
+	} else {
+		err = GetLastError();
+		printf("Could not get device size (error code %d)\n", err);
+		return 1;
+	}
+	if (l.PartitionStyle == PARTITION_STYLE_GPT) {
+		printf("Disk usable length is %llu\n", l.Gpt.UsableLength.QuadPart);
+		l.Gpt.UsableLength.QuadPart += delta;
+		printf("Updating disk usable length to %llu\n", l.Gpt.UsableLength.QuadPart);
+
+		l.PartitionEntry[0].PartitionLength.QuadPart += delta;
+
+		ret = DeviceIoControl(h, IOCTL_DISK_SET_DRIVE_LAYOUT_EX, &l, sizeof(l), NULL, 0, NULL, NULL);
+		if (ret) {
+			printf("Set device size.\n");
+		} else {
+			err = GetLastError();
+			printf("Could not set device size (error code %d)\n", err);
+			return 1;
+		}
+	} else {
+		printf("Disk must have a GPT to make this work.\n");
+		return 1;
+	}
+	return 0;
+}
+
 static int patch_bootsector_op(const char *drive, enum filesystem_ops op)
 {
 	HANDLE h = do_open_device(drive);
@@ -669,7 +760,14 @@ int log_server_op(const char *log_file)
 
 	printf("Waiting for log messages from windrbd kernel driver.\r\n");
 	printf("Press Ctrl-C to stop.\r\n");
-	while ((len = recv(s, buf, sizeof(buf)-1, 0)) >= 0) {
+	while (1) {
+		len = recv(s, buf, sizeof(buf)-1, 0);
+		if (len < 0) {
+			perror("recv");
+			fprintf(stderr, "Could not receive logging packet, retrying again in 1 second\n");
+			sleep(1);
+			continue;
+		}
 		if (len > sizeof(buf)-1)	/* just to be sure ... */
 			len = sizeof(buf)-1;
 
@@ -681,7 +779,7 @@ int log_server_op(const char *log_file)
 				perror("write (ignored)");
 		}
 	}
-	perror("recv");
+	fprintf(stderr, "We should never get here.");
 	return 1;
 }
 
@@ -878,6 +976,7 @@ static int check_for_retvals(void)
 		if (child_pid < 0) {
 			if (errno != ECHILD) {
 				perror("wait");
+				timestamp();
 				printf("Error waiting for child process in signal handler.\n");
 				return -1;
 			}
@@ -895,26 +994,32 @@ static int check_for_retvals(void)
 				else
 					rv.retval = retval;
 
+				if (!quiet) {
+					if (WIFSIGNALED(retval)) {
+						timestamp();
+						printf("handler was terminated by signal %d (id from kernel is %d)\n", WTERMSIG(retval), p->cmd->id);
+					} else {
+						timestamp();
+						printf("handler terminated and returned exit status %d (id from kernel is %d)\n", retval, p->cmd->id);
+					}
+				}
 				free(p->cmd);
 				LIST_REMOVE(p, list_entry);
 				free(p);
 
-				if (!quiet) {
-					if (WIFSIGNALED(retval))
-						printf("handler was terminated by signal %d\n", WTERMSIG(retval));
-					else
-						printf("handler terminated and returned exit status %d\n", retval);
-				}
 				ret = DeviceIoControl(um_root_dev_handle, IOCTL_WINDRBD_ROOT_SEND_USERMODE_HELPER_RETURN_VALUE, &rv, sizeof(rv), NULL, 0, &unused, NULL);
 				if (!ret) {
 					err = GetLastError();
+					timestamp();
 					printf("Error in sending ioctl to kernel, err is %d\n", err);
 				}
 				break;
 			}
 		}
-		if (p == NULL)
+		if (p == NULL) {
+			timestamp();
 			printf("Warning: Process %d not found on process list\n", child_pid);
+		}
 	}
 	return 0;
 }
@@ -967,16 +1072,25 @@ static int exec_command(struct windrbd_usermode_helper *next_cmd)
 	envp[i] = NULL;
 
 	if (!quiet) {
-		printf("about to exec %s ...\n", cmd);
-		for (i=0;argv[i]!=NULL;i++)
+		timestamp();
+		printf("about to exec %s ... (id from kernel is %d)\n", cmd, next_cmd->id);
+		timestamp();
+		for (i=0;argv[i]!=NULL;i++) {
 			printf("%s ", argv[i]);
-		printf("\nEnvironment: \n");
-		for (i=0;envp[i]!=NULL;i++)
+		}
+		printf("\n");
+		timestamp();
+		printf("Environment: \n");
+		for (i=0;envp[i]!=NULL;i++) {
+			timestamp();
 			printf("%s\n", envp[i]);
-		printf("\n(pid is %d)\n", getpid());
+		}
+		timestamp();
+		printf("(pid is %d)\n", getpid());
 	}
 	execvpe(cmd, argv, envp);
 	perror("execvpe");
+	timestamp();
 	printf("Could not exec %s\n", cmd);
 	exit(102);
 }
@@ -987,6 +1101,7 @@ static struct process *add_command_to_process_list(struct windrbd_usermode_helpe
 
 	p = malloc(sizeof(*p));
 	if (p == NULL) {
+		timestamp();
 		printf("Could not allocate memory for process struct\n");
 		return NULL;
 	}
@@ -1008,6 +1123,7 @@ static int fork_and_exec_command(struct windrbd_usermode_helper *next_cmd)
 
 	case -1:
 		perror("fork");
+		timestamp();
 		printf("Cannot fork process\n");
 		return -1;
 
@@ -1024,6 +1140,7 @@ static int get_exe_path(char *buf, size_t bufsize)
 
 	if (fd < 0) {
 		perror("open /proc/self/exename");
+		timestamp();
 		fprintf(stderr, "Could not open /proc/self/exename, does /proc exist?\n");
 
 		return -1;
@@ -1031,6 +1148,7 @@ static int get_exe_path(char *buf, size_t bufsize)
 	len = read(fd, buf, bufsize-1);
 	if (len < 0) {
 		perror("read /proc/self/exename");
+		timestamp();
 		fprintf(stderr, "Could not read /proc/self/exename\n");
 		close(fd);
 
@@ -1049,8 +1167,10 @@ static int print_exe_path(void)
 	int ret;
 
 	ret = get_exe_path(buf, sizeof(buf));
-	if (ret == 0)
+	if (ret == 0) {
+		timestamp();
 		printf("%s\n", buf);
+	}
 
 	return ret;
 }
@@ -1111,9 +1231,21 @@ static int user_mode_helper_daemon(void)
 	BOOL ret;
 
 	if (!quiet) {
+		timestamp();
 		printf("Starting WinDRBD user mode helper daemon\n");
+		timestamp();
 		printf("Press Ctrl-C to stop.\n");
 	}
+	if (dup2(1, 2) < 0) {
+		perror("dup2");
+		timestamp();
+		fprintf(stderr, "Error redirecting stderr to stdout\n");
+	} else {
+		if (!quiet) {
+			timestamp();
+			printf("Redirected stderr to stdout\n");
+		}
+	}
 
 		/* We might be started when the driver isn't started
 		 * yet. Keep on trying until we succeed or get killed.
@@ -1125,8 +1257,10 @@ static int user_mode_helper_daemon(void)
 			break;
 		sleep(1);
 	}
-	if (!quiet)
+	if (!quiet) {
+		timestamp();
 		printf("Connected to WinDRBD kernel driver\n");
+	}
 
 /* Later: */
 /*	set_um_helper(); */
@@ -1135,6 +1269,7 @@ static int user_mode_helper_daemon(void)
 		ret = DeviceIoControl(um_root_dev_handle, IOCTL_WINDRBD_ROOT_RECEIVE_USERMODE_HELPER, NULL, 0, &get_size, sizeof(get_size), &size, NULL);
 		if (!ret) {
 			err = GetLastError();
+			timestamp();
 			printf("Error in sending ioctl to kernel, err is %d\n", err);
 			break;
 		}
@@ -1143,20 +1278,23 @@ static int user_mode_helper_daemon(void)
 
 			next_cmd = malloc(req_size);
 			if (next_cmd == NULL) {
+				timestamp();
 				printf("Could not alloc %zd bytes for command, aborting\n", req_size);
 				break;
 			}
 			ret = DeviceIoControl(um_root_dev_handle, IOCTL_WINDRBD_ROOT_RECEIVE_USERMODE_HELPER, NULL, 0, next_cmd, req_size, &size2, NULL);
 			if (!ret) {
 				err = GetLastError();
+				timestamp();
 				printf("Error in sending ioctl to kernel, err is %d\n", err);
 				break;
 			}
 			if (size2 != req_size) {
-				printf("Size mismatch from ioctl: expected %zd actual %d\n", req_size, size2);
-				break;
+				timestamp();
+				printf("Size mismatch from ioctl: expected %zd actual %d, omitting this request\n", req_size, size2);
+			} else {
+				fork_and_exec_command(next_cmd);
 			}
-			fork_and_exec_command(next_cmd);
 		} /* else nothing to do, wait a little and poll again */
 
 			/* This checks for terminated child processes and
@@ -1347,6 +1485,26 @@ int print_lock_down_state(void)
 	return ret;
 }
 
+int print_bus_device_working(void)
+{
+	int value, ret;
+
+	ret = get_int_ioctl(IOCTL_WINDRBD_ROOT_BUS_DEVICE_IS_WORKING, &value);
+	if (ret == 0) {
+		if (!quiet) {
+			if (value)
+				printf("WinDRBD Virtual Bus Device works as expected.\n");
+			else
+				printf("WinDRBD Virtual Bus Device does NOT work as expected, please recreate\nwindrbd remove-bus-device <inf-file>\nwindrbd install-bus-device <inf-file>\n");
+		}
+		/* return 0 (= success in bash) only if ioctl succeeded
+		 * and ioctl reported bus device working.
+		 */
+		return value ? 0 : 1;
+	}
+	return ret;
+}
+
 void print_windows_error_code(const char *func)
 {
 	int err = GetLastError();
@@ -1496,6 +1654,7 @@ static int install_windrbd_bus_device(int remove, const char *inf_file)
 	TCHAR InfFile[1024];
 	int num_deleted;
 	int ret;
+	int cnt;
 
 	if (load_setupapi() < 0) {
 		fprintf(stderr, "setupapi.dll not found or error loading functions, does it exist at all (see C:\\Windows\\System32)\n");
@@ -1556,9 +1715,14 @@ static int install_windrbd_bus_device(int remove, const char *inf_file)
 			goto cleanup_deviceinfo;
 		}
 		printf("UpdateDriverForPlugAndPlayDevices (.., INSTALLFLAG_FORCE, ..)\n");
-		if (!UpdateDriverForPlugAndPlayDevicesW(0, L"WinDRBD\0\0\0", FullFilePath, INSTALLFLAG_FORCE , &RebootRequired)) {
-			print_windows_error_code("UpdateDriverForPlugAndPlayDevices");
-			goto remove_class;
+		cnt = 0;
+		while (!UpdateDriverForPlugAndPlayDevicesW(0, L"WinDRBD\0\0\0", FullFilePath, INSTALLFLAG_FORCE , &RebootRequired)) {
+			if (GetLastError() != ERROR_TIMEOUT || cnt++ > 10) {
+				print_windows_error_code("UpdateDriverForPlugAndPlayDevices");
+				goto remove_class;
+			}
+			printf("Got ERROR_TIMEOUT from system (%d), retrying in 5 seconds ...\n", cnt);
+			sleep(5);
 		}
 		printf("Installed 1 WinDRBD bus device\n");
 	}
@@ -1628,6 +1792,20 @@ int atoi_or_die(const char *buf)
 	return result;
 }
 
+long long atoll_or_die(const char *buf)
+{
+	char *end;
+	long long result;
+
+	errno = 0;
+	result = strtoll(buf, &end, 10);
+	if (errno == ERANGE || end == buf || (*end != '\0' && !isspace(*end)) ||	   ((int)result != result)) {
+		fprintf(stderr, "Argument should be numeric (might be just out of (64-bit signed int) range)\n");
+		exit(1);
+	}
+	return result;
+}
+
 int main(int argc, char ** argv)
 {
 	const char *op;
@@ -1874,6 +2052,48 @@ int main(int argc, char ** argv)
 
 		return send_int_ioctl(IOCTL_WINDRBD_ROOT_SET_SHUTDOWN_FLAG, the_flag);
 	}
+	if (strcmp(op, "unlock-driver") == 0) {
+		if (argc != optind+1) {
+			usage_and_exit();
+		}
+		return send_int_ioctl(IOCTL_WINDRBD_ROOT_SET_DRIVER_LOCKED, 0);
+	}
+	if (strcmp(op, "lock-driver") == 0) {
+		if (argc != optind+1) {
+			usage_and_exit();
+		}
+		return send_int_ioctl(IOCTL_WINDRBD_ROOT_SET_DRIVER_LOCKED, 1);
+	}
+	if (strcmp(op, "suspend-io-for-minor") == 0) {
+		if (argc != optind+2) {
+			usage_and_exit();
+		}
+		return send_int_ioctl(IOCTL_WINDRBD_ROOT_SET_IO_SUSPENDED_FOR_MINOR, atoi_or_die(argv[optind+1]));
+	}
+	if (strcmp(op, "resume-io-for-minor") == 0) {
+		if (argc != optind+2) {
+			usage_and_exit();
+		}
+		return send_int_ioctl(IOCTL_WINDRBD_ROOT_CLEAR_IO_SUSPENDED_FOR_MINOR, atoi_or_die(argv[optind+1]));
+	}
+	if (strcmp(op, "update-size") == 0) {
+		if (argc != optind+2) {
+			usage_and_exit();
+		}
+		return update_size(argv[optind+1]);
+	}
+	if (strcmp(op, "update-size2") == 0) {
+		if (argc != optind+3) {
+			usage_and_exit();
+		}
+		return update_size2(argv[optind+1], atoll_or_die(argv[optind+2]));
+	}
+	if (strcmp(op, "bus-device-is-working") == 0) {
+		if (argc != optind+1) {
+			usage_and_exit();
+		}
+		return print_bus_device_working();
+	}
 
 	usage_and_exit();
 	return 0;
